@@ -394,6 +394,15 @@ class Tapis(object):
         if not self.account_type:
             self.account_type = 'user'
 
+        # Check that access_token and jwt don't collide. (jwt becomes access_token, but shouldn't overwrite another set access_token)
+        if access_token and jwt:
+            raise errors.TapyClientConfigurationError("access_token and jwt can't both be inputs to Tapis.")
+
+        # pass in a "raw" JWT directly. This is only used if the access_token is not set.
+        self.jwt = jwt
+        if jwt:
+            access_token = jwt
+
         # the access token to use -- should be an honest TapisResult access token.
         if access_token and type(access_token) == str:
             # if the access_token passed is a string, convert it to an honest TapisResult token:
@@ -408,10 +417,6 @@ class Tapis(object):
             refresh_token = self.add_claims_to_token(tok)
         self.refresh_token = refresh_token
 
-        # pass in a "raw" JWT directly. This is only used if the access_token is not set.
-        self.jwt = jwt
-        self.access_token = jwt
-
         # whether to verify the TLS certificate at the base_url
         self.verify = verify
 
